# Generated by Django 4.1.10 on 2023-09-06 14:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wbcrm", "0005_account_accountrole_accountroletype_and_more"),
        ("wbcommission", "0002_commissionrule_remove_accountcustomer_account_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="commission",
            name="account",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="account_commissions",
                to="wbcrm.account",
                verbose_name="Account",
            ),
        ),
    ]
